use std::time::Duration;

use super::{Cookie, SameSite};

pub struct CookieBuilder {
    inner: Cookie,
}

impl CookieBuilder {
    pub fn build(name: &str, value: &str) -> Self {
        CookieBuilder {
            inner: Cookie {
                cookie_string: None,
                name: name.to_owned(),
                value: value.to_owned(),
                max_age: None,
                domain: None,
                path: None,
                secure: None,
                http_only: None,
                same_site: None,
                expires: None,
                partitioned: None,
            },
        }
    }
    pub fn finish(self) -> Cookie {
        self.inner
    }
    pub fn max_age(mut self, duration: Duration) -> Self {
        self.inner.max_age = Some(duration);
        self
    }
    pub fn domain(mut self, domain: &str) -> Self {
        self.inner.domain = Some(domain.to_owned());
        self
    }
    pub fn path(mut self, path: &str) -> Self {
        self.inner.path = Some(path.to_owned());
        self
    }
    pub fn secure(mut self, secure: bool) -> Self {
        self.inner.secure = Some(secure);
        self
    }
    pub fn http_only(mut self, http_only: bool) -> Self {
        self.inner.http_only = Some(http_only);
        self
    }
    pub fn same_site(mut self, same_site: SameSite) -> Self {
        self.inner.same_site = Some(same_site);
        self
    }
    pub fn expires(mut self, expire: &str) -> Self {
        self.inner.expires = Some(expire.to_owned());
        self
    }
    pub fn partitioned(mut self, partitioned: bool) -> Self {
        self.inner.partitioned = Some(partitioned);
        self
    }
    pub fn name(mut self, name: &str) -> Self {
        self.inner.name = name.to_owned();
        self
    }
    pub fn value(mut self, value: &str) -> Self {
        self.inner.value = value.to_owned();
        self
    }
}
